# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.h2o.featurestore.api.v1 import CoreService_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2
from ai.h2o.featurestore.api.v1 import DashboardApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_DashboardApi__pb2
from ai.h2o.featurestore.api.v1 import OnlineApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2
from ai.h2o.featurestore.api.v1 import RecommendationProtoApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class CoreServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListJobs = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListJobs',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsResponse.FromString,
                )
        self.GetJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.Job.FromString,
                )
        self.GetJobProgress = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetJobProgress',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressInput.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressOutput.FromString,
                )
        self.CancelJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CancelJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListJobsPageByFeatureSetName = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListJobsPageByFeatureSetName',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageByFeatureSetNameRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageResponse.FromString,
                )
        self.ListJobsPageByFeatureSetId = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListJobsPageByFeatureSetId',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageByFeatureSetIdRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageResponse.FromString,
                )
        self.GetJobsWithStatusCount = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetJobsWithStatusCount',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetJobsWithStatusCountRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetJobsWithStatusCountResponse.FromString,
                )
        self.StartExtractSchemaJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartExtractSchemaJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartExtractSchemaJobRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetExtractSchemaJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetExtractSchemaJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExtractSchemaResponse.FromString,
                )
        self.StartIngestJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartIngestJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartIngestJobRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetIngestJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetIngestJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestResponse.FromString,
                )
        self.StartRetrieveAsLinksJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartRetrieveAsLinksJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetRetrieveAsLinksJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetRetrieveAsLinksJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsLinksResponse.FromString,
                )
        self.RetrieveAsSpark = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RetrieveAsSpark',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsSparkResponse.FromString,
                )
        self.GetIngestWriteCredentials = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetIngestWriteCredentials',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialResponse.FromString,
                )
        self.StartRevertIngestJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartRevertIngestJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartRevertIngestJobRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetRevertIngestJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetRevertIngestJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.HasPermissionToRetrieve = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/HasPermissionToRetrieve',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveResponse.FromString,
                )
        self.RegisterFeatureSet = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RegisterFeatureSet',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RegisterFeatureSetRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
                )
        self.CreateNewFeatureSetVersion = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CreateNewFeatureSetVersion',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateNewFeatureSetVersionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
                )
        self.GetOnlineRetrieveMeta = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetOnlineRetrieveMeta',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.OnlineRetrieveMeta.FromString,
                )
        self.GetVersion = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetVersion',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetVersionResponse.FromString,
                )
        self.GetFeatureSet = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSet',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
                )
        self.GetFeatureSetById = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetById',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetRequestId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
                )
        self.GetFeatureSetsLastMinorForCurrentMajor = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetsLastMinorForCurrentMajor',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetsLastMinorForCurrentMajorRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
                )
        self.ListFeatureSetVersions = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetVersions',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsVersionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetVersionsResponse.FromString,
                )
        self.DeleteFeatureSet = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureSet',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureSetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteFeatureSetVersion = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureSetVersion',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureSetVersionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListFeatureSetsPage = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetsPage',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPageRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPageResponse.FromString,
                )
        self.FeatureSetExists = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/FeatureSetExists',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetExistsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
                )
        self.GetIngestHistory = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetIngestHistory',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryResponse.FromString,
                )
        self.IsFeatureSetSchemaCompatible = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/IsFeatureSetSchemaCompatible',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityResponse.FromString,
                )
        self.FeatureSetSchemaPatch = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/FeatureSetSchemaPatch',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchResponse.FromString,
                )
        self.GetFeatureSetPreview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetPreview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewResponse.FromString,
                )
        self.UpdateFeatureSet = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSet',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureSetRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureSetResponse.FromString,
                )
        self.CreateFeatureView = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CreateFeatureView',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateFeatureViewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.FromString,
                )
        self.UpdateFeatureView = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureView',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureViewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.FromString,
                )
        self.GetFeatureView = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureView',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureViewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.FromString,
                )
        self.FeatureViewExists = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/FeatureViewExists',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewExistsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
                )
        self.ListFeatureViews = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureViews',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureViewsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureViewsResponse.FromString,
                )
        self.CreateFeatureViewNewVersion = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CreateFeatureViewNewVersion',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateFeatureViewNewVersionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.FromString,
                )
        self.StartRetrieveFeatureViewAsSparkJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartRetrieveFeatureViewAsSparkJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsSparkRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetRetrieveFeatureViewAsSparkJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetRetrieveFeatureViewAsSparkJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsSparkResponse.FromString,
                )
        self.StartRetrieveFeatureViewAsLinksJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartRetrieveFeatureViewAsLinksJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsAsLinksRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetRetrieveFeatureViewAsLinksJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetRetrieveFeatureViewAsLinksJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsAsLinksResponse.FromString,
                )
        self.DeleteFeatureView = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureView',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureViewRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateMLDataset = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CreateMLDataset',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateMLDatasetRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateMLDatasetResponse.FromString,
                )
        self.GetMLDatasetCreationJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetMLDatasetCreationJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDataset.FromString,
                )
        self.UpdateMLDataset = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateMLDataset',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateMLDatasetRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDataset.FromString,
                )
        self.DeleteMLDataset = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteMLDataset',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteMLDatasetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetMLDataset = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetMLDataset',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetMLDatasetRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDataset.FromString,
                )
        self.MLDatasetExists = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/MLDatasetExists',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDatasetExistsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
                )
        self.ListMLDatasets = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListMLDatasets',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListMLDatasetsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListMLDatasetsResponse.FromString,
                )
        self.RetrieveMLDatasetAsSpark = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RetrieveMLDatasetAsSpark',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsSparkRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsSparkResponse.FromString,
                )
        self.RetrieveMLDatasetAsLinks = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RetrieveMLDatasetAsLinks',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsAsLinksRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsAsLinksResponse.FromString,
                )
        self.RetrieveMLDatasetOnline = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RetrieveMLDatasetOnline',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetOnlineRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveResponse.FromString,
                )
        self.ListProjectsPage = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListProjectsPage',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPageRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPageResponse.FromString,
                )
        self.CreateProject = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CreateProject',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectResponse.FromString,
                )
        self.GetProject = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetProject',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetProjectRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.FromString,
                )
        self.DeleteProject = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteProject',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteProjectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetProjectsDefault = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetProjectsDefault',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectsDefaultResponse.FromString,
                )
        self.ProjectExists = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ProjectExists',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectExistsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
                )
        self.UpdateProject = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateProject',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateProjectResponse.FromString,
                )
        self.ListProjectHistoryPage = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListProjectHistoryPage',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectHistoryPageRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectHistoryPageResponse.FromString,
                )
        self.GetAccessToken = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetAccessToken',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RefreshTokenRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.AccessTokenResponse.FromString,
                )
        self.GetUserByMail = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetUserByMail',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailResponse.FromString,
                )
        self.Logout = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/Logout',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LogoutRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetActiveUser = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetActiveUser',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActiveUserResponse.FromString,
                )
        self.Login = channel.unary_stream(
                '/ai.h2o.featurestore.api.v1.CoreService/Login',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LoginResponse.FromString,
                )
        self.GetWebConfig = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetWebConfig',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetWebConfigResponse.FromString,
                )
        self.AddFeatureSetPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/AddFeatureSetPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.AddProjectPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/AddProjectPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RemoveFeatureSetPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RemoveFeatureSetPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RemoveProjectPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RemoveProjectPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.SubmitPendingProjectPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/SubmitPendingProjectPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionResponse.FromString,
                )
        self.SubmitPendingFeatureSetPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/SubmitPendingFeatureSetPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionResponse.FromString,
                )
        self.ListProjectPermissionsPage = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListProjectPermissionsPage',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPermissionsPageResponse.FromString,
                )
        self.ListFeatureSetsPermissionsPage = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetsPermissionsPage',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPermissionsPageResponse.FromString,
                )
        self.ListManageableProjectPermissionsPage = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListManageableProjectPermissionsPage',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPermissionsPageResponse.FromString,
                )
        self.ListManageableFeatureSetsPermissionsPage = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListManageableFeatureSetsPermissionsPage',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPermissionsPageResponse.FromString,
                )
        self.ApprovePendingPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ApprovePendingPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ApprovePendingPermissionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RejectPendingPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RejectPendingPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RejectPendingPermissionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RevokePermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RevokePermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RevokePermissionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetActiveProjectPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetActiveProjectPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionResponse.FromString,
                )
        self.GetActiveFeatureSetPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetActiveFeatureSetPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionResponse.FromString,
                )
        self.GetProjectOwners = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetProjectOwners',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersResponse.FromString,
                )
        self.GetFeatureSetOwners = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetOwners',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersResponse.FromString,
                )
        self.GetUserProjectPermissions = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetUserProjectPermissions',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsResponse.FromString,
                )
        self.GetUserFeatureSetPermissions = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetUserFeatureSetPermissions',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsResponse.FromString,
                )
        self.RevokeToken = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RevokeToken',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GenerateToken = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GenerateToken',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTokenRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RawTokenResponse.FromString,
                )
        self.ListTokens = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListTokens',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTokensResponse.FromString,
                )
        self.ListPersonalAccessTokens = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListPersonalAccessTokens',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPersonalAccessTokensRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPersonalAccessTokensResponse.FromString,
                )
        self.GetToken = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetToken',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenResponse.FromString,
                )
        self.OnlineRetrieve = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/OnlineRetrieve',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveResponse.FromString,
                )
        self.OnlineIngest = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/OnlineIngest',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineIngestRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StartMaterializationOnlineJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartMaterializationOnlineJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartMaterializationOnlineRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetMaterializationOnlineJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetMaterializationOnlineJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MaterializationOnlineResponse.FromString,
                )
        self.GetComputeStatisticsJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetComputeStatisticsJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetComputeRecommendationClassifiersJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetComputeRecommendationClassifiersJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GenerateTransformationUpload = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GenerateTransformationUpload',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadResponse.FromString,
                )
        self.ListRecommendationClassifiers = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListRecommendationClassifiers',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.ListRecommendationClassifierResponse.FromString,
                )
        self.CreateRecommendationClassifier = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CreateRecommendationClassifier',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.CreateRecommendationClassifierRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateRecommendationClassifier = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateRecommendationClassifier',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.UpdateRecommendationClassifierRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteRecommendationClassifier = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteRecommendationClassifier',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.DeleteRecommendationClassifierRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetRecommendations = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetRecommendations',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationResponse.FromString,
                )
        self.GetDashboard = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetDashboard',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_DashboardApi__pb2.DashboardResponse.FromString,
                )
        self.GetFeatureSetsPopularity = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetsPopularity',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetsPopularityResponse.FromString,
                )
        self.GetRecentlyUsedProjects = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetRecentlyUsedProjects',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RecentlyUsedProjectsResponse.FromString,
                )
        self.GetRecentlyUsedFeatureSets = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetRecentlyUsedFeatureSets',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RecentlyUsedFeatureSetsResponse.FromString,
                )
        self.PinFeatureSet = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/PinFeatureSet',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PinFeatureSetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UnpinFeatureSet = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UnpinFeatureSet',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UnpinFeatureSetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.IsFeatureSetPinned = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/IsFeatureSetPinned',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IsFeatureSetPinnedRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IsFeatureSetPinnedResponse.FromString,
                )
        self.ListPinnedFeatureSets = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListPinnedFeatureSets',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PinnedFeatureSetsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PinnedFeatureSetsResponse.FromString,
                )
        self.SearchProjects = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/SearchProjects',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectSearchRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectSearchResults.FromString,
                )
        self.SearchFeatureSets = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/SearchFeatureSets',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSearchRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSearchResults.FromString,
                )
        self.SearchFeatures = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/SearchFeatures',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSearchRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSearchResults.FromString,
                )
        self.GetFeature = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeature',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureResponse.FromString,
                )
        self.ListFeatures = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeatures',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesResponse.FromString,
                )
        self.UpdateFeature = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeature',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureResponse.FromString,
                )
        self.MarkFeatureAsTarget = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/MarkFeatureAsTarget',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TargetFeatureRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DiscardFeatureAsTarget = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DiscardFeatureAsTarget',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TargetFeatureRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListTargetFeatures = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListTargetFeatures',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTargetFeaturesRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTargetFeaturesResponse.FromString,
                )
        self.GetListableFeatureSet = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetListableFeatureSet',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListableFeatureSetRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListableFeatureSetResponse.FromString,
                )
        self.ScheduleIngestJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ScheduleIngestJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduleTaskRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.FromString,
                )
        self.ListScheduledTasks = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListScheduledTasks',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTasksRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTasksResponse.FromString,
                )
        self.GetScheduledTask = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetScheduledTask',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.FromString,
                )
        self.DeleteScheduledTask = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteScheduledTask',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskId.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateScheduledTask = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateScheduledTask',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PauseScheduledTask = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/PauseScheduledTask',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PauseScheduledTaskRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ResumeScheduledTask = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ResumeScheduledTask',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ResumeScheduledTaskRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ScheduleLazyIngestTask = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ScheduleLazyIngestTask',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduleTaskRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.FromString,
                )
        self.StartLazyIngestTask = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartLazyIngestTask',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LazyIngestRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LazyIngestResponse.FromString,
                )
        self.GetLazyIngestTask = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetLazyIngestTask',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetLazyIngestTaskRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.FromString,
                )
        self.ListScheduledTaskExecutionHistory = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListScheduledTaskExecutionHistory',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTaskExecutionsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTaskExecutionsResponse.FromString,
                )
        self.ListTransformationFunctions = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListTransformationFunctions',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTransformationFunctionsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTransformationFunctionsResponse.FromString,
                )
        self.GetTransformationFunction = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetTransformationFunction',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetTransformationFunctionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetTransformationFunctionResponse.FromString,
                )
        self.GetBackfillJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetBackfillJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.BackfillResponse.FromString,
                )
        self.CreateDraftFeatureSet = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CreateDraftFeatureSet',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateFeatureSetFromDraft = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CreateFeatureSetFromDraft',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DraftToFeatureSetRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DraftToFeatureSetResponse.FromString,
                )
        self.DeleteFeatureSetDraft = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureSetDraft',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftId.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListFeatureSetDrafts = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetDrafts',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetDraftsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetDraftsResponse.FromString,
                )
        self.GetFeatureSetDraft = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetDraft',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftResponse.FromString,
                )
        self.StoreFileArtifact = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StoreFileArtifact',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StoreFileArtifactRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StoreFileArtifactResponse.FromString,
                )
        self.RetrieveArtifact = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RetrieveArtifact',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveArtifactRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveArtifactResponse.FromString,
                )
        self.UpdateUploadStatus = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateUploadStatus',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateUploadStatusRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteArtifact = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteArtifact',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteArtifactRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListArtifacts = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListArtifacts',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListArtifactsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListArtifactsResponse.FromString,
                )
        self.StoreLink = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StoreLink',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StoreLinkRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListFeatureSetsToReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetsToReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsToReviewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsToReviewResponse.FromString,
                )
        self.ApproveReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ApproveReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ApproveReviewRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RejectReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RejectReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RejectReviewRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListFeatureSetsReviewsPage = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetsReviewsPage',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetReviewsPageRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetReviewsPageResponse.FromString,
                )
        self.GetListableFeatureSetToReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetListableFeatureSetToReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetToReviewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetToReviewResponse.FromString,
                )
        self.GetListableFeatureSetInReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetListableFeatureSetInReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetInReviewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetInReviewResponse.FromString,
                )
        self.DeleteFeatureSetVersionInReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureSetVersionInReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteRejectedFeatureSetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListFeaturesToReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeaturesToReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesToReviewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesToReviewResponse.FromString,
                )
        self.ListFeaturesInReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeaturesInReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesInReviewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesInReviewResponse.FromString,
                )
        self.GetFeatureSetPreviewToReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetPreviewToReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewToReviewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewToReviewResponse.FromString,
                )
        self.GetFeatureSetPreviewInReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetPreviewInReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewInReviewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewInReviewResponse.FromString,
                )
        self.GetFeatureSetToReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetToReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetToReviewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetToReviewResponse.FromString,
                )
        self.GetFeatureSetInReview = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetInReview',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetInReviewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetInReviewResponse.FromString,
                )


class CoreServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListJobs(self, request, context):
        """Jobs API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJobProgress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListJobsPageByFeatureSetName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListJobsPageByFeatureSetId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJobsWithStatusCount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartExtractSchemaJob(self, request, context):
        """Extract Schema API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExtractSchemaJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartIngestJob(self, request, context):
        """Feature Set API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIngestJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartRetrieveAsLinksJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRetrieveAsLinksJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveAsSpark(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIngestWriteCredentials(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartRevertIngestJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRevertIngestJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HasPermissionToRetrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNewFeatureSetVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOnlineRetrieveMeta(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetsLastMinorForCurrentMajor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureSetVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureSetVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureSetsPage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeatureSetExists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIngestHistory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsFeatureSetSchemaCompatible(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeatureSetSchemaPatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetPreview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeatureView(self, request, context):
        """Feature View API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureView(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureView(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeatureViewExists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureViews(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeatureViewNewVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartRetrieveFeatureViewAsSparkJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRetrieveFeatureViewAsSparkJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartRetrieveFeatureViewAsLinksJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRetrieveFeatureViewAsLinksJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureView(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMLDataset(self, request, context):
        """ML Dataset API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMLDatasetCreationJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMLDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMLDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMLDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MLDatasetExists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMLDatasets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveMLDatasetAsSpark(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveMLDatasetAsLinks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveMLDatasetOnline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProjectsPage(self, request, context):
        """Project API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjectsDefault(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProjectExists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProjectHistoryPage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccessToken(self, request, context):
        """Auth API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserByMail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWebConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddFeatureSetPermission(self, request, context):
        """Permissions API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddProjectPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveFeatureSetPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveProjectPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitPendingProjectPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitPendingFeatureSetPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProjectPermissionsPage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureSetsPermissionsPage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListManageableProjectPermissionsPage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListManageableFeatureSetsPermissionsPage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApprovePendingPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RejectPendingPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokePermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveProjectPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveFeatureSetPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjectOwners(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetOwners(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserProjectPermissions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserFeatureSetPermissions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeToken(self, request, context):
        """PAT API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTokens(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPersonalAccessTokens(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnlineRetrieve(self, request, context):
        """Online API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnlineIngest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartMaterializationOnlineJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMaterializationOnlineJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetComputeStatisticsJobOutput(self, request, context):
        """ComputeStatistics API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetComputeRecommendationClassifiersJobOutput(self, request, context):
        """ComputeRecommendationClassifier API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateTransformationUpload(self, request, context):
        """Upload API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRecommendationClassifiers(self, request, context):
        """Recommendation API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRecommendationClassifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRecommendationClassifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRecommendationClassifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecommendations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDashboard(self, request, context):
        """Dashboard API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetsPopularity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecentlyUsedProjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecentlyUsedFeatureSets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PinFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnpinFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsFeatureSetPinned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPinnedFeatureSets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchProjects(self, request, context):
        """Search API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchFeatureSets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchFeatures(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeature(self, request, context):
        """Feature API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatures(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeature(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarkFeatureAsTarget(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DiscardFeatureAsTarget(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTargetFeatures(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetListableFeatureSet(self, request, context):
        """Listable FeatureSet API (in future will be moved to new file)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScheduleIngestJob(self, request, context):
        """Schedule API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListScheduledTasks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScheduledTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteScheduledTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateScheduledTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseScheduledTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeScheduledTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScheduleLazyIngestTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartLazyIngestTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLazyIngestTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListScheduledTaskExecutionHistory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTransformationFunctions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransformationFunction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBackfillJobOutput(self, request, context):
        """Backfill
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDraftFeatureSet(self, request, context):
        """Draft Feature Set
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeatureSetFromDraft(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureSetDraft(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureSetDrafts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetDraft(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StoreFileArtifact(self, request, context):
        """Artifact
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveArtifact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUploadStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteArtifact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListArtifacts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StoreLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureSetsToReview(self, request, context):
        """Feature Set Review
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApproveReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RejectReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureSetsReviewsPage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetListableFeatureSetToReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetListableFeatureSetInReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureSetVersionInReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeaturesToReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeaturesInReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetPreviewToReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetPreviewInReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetToReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetInReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListJobs,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsResponse.SerializeToString,
            ),
            'GetJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.Job.SerializeToString,
            ),
            'GetJobProgress': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJobProgress,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressInput.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressOutput.SerializeToString,
            ),
            'CancelJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListJobsPageByFeatureSetName': grpc.unary_unary_rpc_method_handler(
                    servicer.ListJobsPageByFeatureSetName,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageByFeatureSetNameRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageResponse.SerializeToString,
            ),
            'ListJobsPageByFeatureSetId': grpc.unary_unary_rpc_method_handler(
                    servicer.ListJobsPageByFeatureSetId,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageByFeatureSetIdRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageResponse.SerializeToString,
            ),
            'GetJobsWithStatusCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJobsWithStatusCount,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetJobsWithStatusCountRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetJobsWithStatusCountResponse.SerializeToString,
            ),
            'StartExtractSchemaJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartExtractSchemaJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartExtractSchemaJobRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetExtractSchemaJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtractSchemaJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExtractSchemaResponse.SerializeToString,
            ),
            'StartIngestJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartIngestJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartIngestJobRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetIngestJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIngestJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestResponse.SerializeToString,
            ),
            'StartRetrieveAsLinksJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartRetrieveAsLinksJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetRetrieveAsLinksJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRetrieveAsLinksJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsLinksResponse.SerializeToString,
            ),
            'RetrieveAsSpark': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveAsSpark,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsSparkResponse.SerializeToString,
            ),
            'GetIngestWriteCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIngestWriteCredentials,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialResponse.SerializeToString,
            ),
            'StartRevertIngestJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartRevertIngestJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartRevertIngestJobRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetRevertIngestJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRevertIngestJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'HasPermissionToRetrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.HasPermissionToRetrieve,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveResponse.SerializeToString,
            ),
            'RegisterFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterFeatureSet,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RegisterFeatureSetRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.SerializeToString,
            ),
            'CreateNewFeatureSetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNewFeatureSetVersion,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateNewFeatureSetVersionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.SerializeToString,
            ),
            'GetOnlineRetrieveMeta': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOnlineRetrieveMeta,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.OnlineRetrieveMeta.SerializeToString,
            ),
            'GetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVersion,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetVersionResponse.SerializeToString,
            ),
            'GetFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSet,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.SerializeToString,
            ),
            'GetFeatureSetById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetById,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetRequestId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.SerializeToString,
            ),
            'GetFeatureSetsLastMinorForCurrentMajor': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetsLastMinorForCurrentMajor,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetsLastMinorForCurrentMajorRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.SerializeToString,
            ),
            'ListFeatureSetVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSetVersions,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsVersionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetVersionsResponse.SerializeToString,
            ),
            'DeleteFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureSet,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureSetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteFeatureSetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureSetVersion,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureSetVersionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListFeatureSetsPage': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSetsPage,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPageRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPageResponse.SerializeToString,
            ),
            'FeatureSetExists': grpc.unary_unary_rpc_method_handler(
                    servicer.FeatureSetExists,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetExistsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.SerializeToString,
            ),
            'GetIngestHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIngestHistory,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryResponse.SerializeToString,
            ),
            'IsFeatureSetSchemaCompatible': grpc.unary_unary_rpc_method_handler(
                    servicer.IsFeatureSetSchemaCompatible,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityResponse.SerializeToString,
            ),
            'FeatureSetSchemaPatch': grpc.unary_unary_rpc_method_handler(
                    servicer.FeatureSetSchemaPatch,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchResponse.SerializeToString,
            ),
            'GetFeatureSetPreview': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetPreview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewResponse.SerializeToString,
            ),
            'UpdateFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSet,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureSetRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureSetResponse.SerializeToString,
            ),
            'CreateFeatureView': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeatureView,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateFeatureViewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.SerializeToString,
            ),
            'UpdateFeatureView': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureView,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureViewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.SerializeToString,
            ),
            'GetFeatureView': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureView,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureViewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.SerializeToString,
            ),
            'FeatureViewExists': grpc.unary_unary_rpc_method_handler(
                    servicer.FeatureViewExists,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewExistsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.SerializeToString,
            ),
            'ListFeatureViews': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureViews,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureViewsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureViewsResponse.SerializeToString,
            ),
            'CreateFeatureViewNewVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeatureViewNewVersion,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateFeatureViewNewVersionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.SerializeToString,
            ),
            'StartRetrieveFeatureViewAsSparkJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartRetrieveFeatureViewAsSparkJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsSparkRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetRetrieveFeatureViewAsSparkJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRetrieveFeatureViewAsSparkJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsSparkResponse.SerializeToString,
            ),
            'StartRetrieveFeatureViewAsLinksJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartRetrieveFeatureViewAsLinksJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsAsLinksRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetRetrieveFeatureViewAsLinksJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRetrieveFeatureViewAsLinksJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsAsLinksResponse.SerializeToString,
            ),
            'DeleteFeatureView': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureView,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureViewRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateMLDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMLDataset,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateMLDatasetRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateMLDatasetResponse.SerializeToString,
            ),
            'GetMLDatasetCreationJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMLDatasetCreationJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDataset.SerializeToString,
            ),
            'UpdateMLDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMLDataset,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateMLDatasetRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDataset.SerializeToString,
            ),
            'DeleteMLDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMLDataset,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteMLDatasetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetMLDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMLDataset,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetMLDatasetRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDataset.SerializeToString,
            ),
            'MLDatasetExists': grpc.unary_unary_rpc_method_handler(
                    servicer.MLDatasetExists,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDatasetExistsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.SerializeToString,
            ),
            'ListMLDatasets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMLDatasets,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListMLDatasetsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListMLDatasetsResponse.SerializeToString,
            ),
            'RetrieveMLDatasetAsSpark': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveMLDatasetAsSpark,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsSparkRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsSparkResponse.SerializeToString,
            ),
            'RetrieveMLDatasetAsLinks': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveMLDatasetAsLinks,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsAsLinksRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsAsLinksResponse.SerializeToString,
            ),
            'RetrieveMLDatasetOnline': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveMLDatasetOnline,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetOnlineRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveResponse.SerializeToString,
            ),
            'ListProjectsPage': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjectsPage,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPageRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPageResponse.SerializeToString,
            ),
            'CreateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateProject,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectResponse.SerializeToString,
            ),
            'GetProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProject,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetProjectRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.SerializeToString,
            ),
            'DeleteProject': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProject,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteProjectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetProjectsDefault': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjectsDefault,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectsDefaultResponse.SerializeToString,
            ),
            'ProjectExists': grpc.unary_unary_rpc_method_handler(
                    servicer.ProjectExists,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectExistsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.SerializeToString,
            ),
            'UpdateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProject,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateProjectRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateProjectResponse.SerializeToString,
            ),
            'ListProjectHistoryPage': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjectHistoryPage,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectHistoryPageRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectHistoryPageResponse.SerializeToString,
            ),
            'GetAccessToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccessToken,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RefreshTokenRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.AccessTokenResponse.SerializeToString,
            ),
            'GetUserByMail': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserByMail,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailResponse.SerializeToString,
            ),
            'Logout': grpc.unary_unary_rpc_method_handler(
                    servicer.Logout,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LogoutRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetActiveUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActiveUser,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActiveUserResponse.SerializeToString,
            ),
            'Login': grpc.unary_stream_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LoginResponse.SerializeToString,
            ),
            'GetWebConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWebConfig,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetWebConfigResponse.SerializeToString,
            ),
            'AddFeatureSetPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.AddFeatureSetPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'AddProjectPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.AddProjectPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RemoveFeatureSetPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveFeatureSetPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RemoveProjectPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveProjectPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'SubmitPendingProjectPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitPendingProjectPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionResponse.SerializeToString,
            ),
            'SubmitPendingFeatureSetPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitPendingFeatureSetPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionResponse.SerializeToString,
            ),
            'ListProjectPermissionsPage': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjectPermissionsPage,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPermissionsPageResponse.SerializeToString,
            ),
            'ListFeatureSetsPermissionsPage': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSetsPermissionsPage,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPermissionsPageResponse.SerializeToString,
            ),
            'ListManageableProjectPermissionsPage': grpc.unary_unary_rpc_method_handler(
                    servicer.ListManageableProjectPermissionsPage,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPermissionsPageResponse.SerializeToString,
            ),
            'ListManageableFeatureSetsPermissionsPage': grpc.unary_unary_rpc_method_handler(
                    servicer.ListManageableFeatureSetsPermissionsPage,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPermissionsPageResponse.SerializeToString,
            ),
            'ApprovePendingPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.ApprovePendingPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ApprovePendingPermissionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RejectPendingPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.RejectPendingPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RejectPendingPermissionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RevokePermission': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokePermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RevokePermissionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetActiveProjectPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActiveProjectPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionResponse.SerializeToString,
            ),
            'GetActiveFeatureSetPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActiveFeatureSetPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionResponse.SerializeToString,
            ),
            'GetProjectOwners': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjectOwners,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersResponse.SerializeToString,
            ),
            'GetFeatureSetOwners': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetOwners,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersResponse.SerializeToString,
            ),
            'GetUserProjectPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserProjectPermissions,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsResponse.SerializeToString,
            ),
            'GetUserFeatureSetPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserFeatureSetPermissions,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsResponse.SerializeToString,
            ),
            'RevokeToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeToken,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GenerateToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateToken,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTokenRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RawTokenResponse.SerializeToString,
            ),
            'ListTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTokens,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTokensResponse.SerializeToString,
            ),
            'ListPersonalAccessTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPersonalAccessTokens,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPersonalAccessTokensRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPersonalAccessTokensResponse.SerializeToString,
            ),
            'GetToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetToken,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenResponse.SerializeToString,
            ),
            'OnlineRetrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.OnlineRetrieve,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveResponse.SerializeToString,
            ),
            'OnlineIngest': grpc.unary_unary_rpc_method_handler(
                    servicer.OnlineIngest,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineIngestRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StartMaterializationOnlineJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartMaterializationOnlineJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartMaterializationOnlineRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetMaterializationOnlineJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMaterializationOnlineJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MaterializationOnlineResponse.SerializeToString,
            ),
            'GetComputeStatisticsJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetComputeStatisticsJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetComputeRecommendationClassifiersJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetComputeRecommendationClassifiersJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GenerateTransformationUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateTransformationUpload,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadResponse.SerializeToString,
            ),
            'ListRecommendationClassifiers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRecommendationClassifiers,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.ListRecommendationClassifierResponse.SerializeToString,
            ),
            'CreateRecommendationClassifier': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRecommendationClassifier,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.CreateRecommendationClassifierRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateRecommendationClassifier': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRecommendationClassifier,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.UpdateRecommendationClassifierRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteRecommendationClassifier': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRecommendationClassifier,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.DeleteRecommendationClassifierRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetRecommendations': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecommendations,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationResponse.SerializeToString,
            ),
            'GetDashboard': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDashboard,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_DashboardApi__pb2.DashboardResponse.SerializeToString,
            ),
            'GetFeatureSetsPopularity': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetsPopularity,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetsPopularityResponse.SerializeToString,
            ),
            'GetRecentlyUsedProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecentlyUsedProjects,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RecentlyUsedProjectsResponse.SerializeToString,
            ),
            'GetRecentlyUsedFeatureSets': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecentlyUsedFeatureSets,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RecentlyUsedFeatureSetsResponse.SerializeToString,
            ),
            'PinFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.PinFeatureSet,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PinFeatureSetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UnpinFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.UnpinFeatureSet,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UnpinFeatureSetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'IsFeatureSetPinned': grpc.unary_unary_rpc_method_handler(
                    servicer.IsFeatureSetPinned,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IsFeatureSetPinnedRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IsFeatureSetPinnedResponse.SerializeToString,
            ),
            'ListPinnedFeatureSets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPinnedFeatureSets,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PinnedFeatureSetsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PinnedFeatureSetsResponse.SerializeToString,
            ),
            'SearchProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchProjects,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectSearchRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectSearchResults.SerializeToString,
            ),
            'SearchFeatureSets': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchFeatureSets,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSearchRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSearchResults.SerializeToString,
            ),
            'SearchFeatures': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchFeatures,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSearchRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSearchResults.SerializeToString,
            ),
            'GetFeature': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeature,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureResponse.SerializeToString,
            ),
            'ListFeatures': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatures,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesResponse.SerializeToString,
            ),
            'UpdateFeature': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeature,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureResponse.SerializeToString,
            ),
            'MarkFeatureAsTarget': grpc.unary_unary_rpc_method_handler(
                    servicer.MarkFeatureAsTarget,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TargetFeatureRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DiscardFeatureAsTarget': grpc.unary_unary_rpc_method_handler(
                    servicer.DiscardFeatureAsTarget,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TargetFeatureRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListTargetFeatures': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTargetFeatures,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTargetFeaturesRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTargetFeaturesResponse.SerializeToString,
            ),
            'GetListableFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.GetListableFeatureSet,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListableFeatureSetRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListableFeatureSetResponse.SerializeToString,
            ),
            'ScheduleIngestJob': grpc.unary_unary_rpc_method_handler(
                    servicer.ScheduleIngestJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduleTaskRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.SerializeToString,
            ),
            'ListScheduledTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListScheduledTasks,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTasksRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTasksResponse.SerializeToString,
            ),
            'GetScheduledTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetScheduledTask,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.SerializeToString,
            ),
            'DeleteScheduledTask': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteScheduledTask,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskId.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateScheduledTask': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateScheduledTask,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PauseScheduledTask': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseScheduledTask,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PauseScheduledTaskRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ResumeScheduledTask': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeScheduledTask,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ResumeScheduledTaskRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ScheduleLazyIngestTask': grpc.unary_unary_rpc_method_handler(
                    servicer.ScheduleLazyIngestTask,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduleTaskRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.SerializeToString,
            ),
            'StartLazyIngestTask': grpc.unary_unary_rpc_method_handler(
                    servicer.StartLazyIngestTask,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LazyIngestRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LazyIngestResponse.SerializeToString,
            ),
            'GetLazyIngestTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLazyIngestTask,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetLazyIngestTaskRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.SerializeToString,
            ),
            'ListScheduledTaskExecutionHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.ListScheduledTaskExecutionHistory,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTaskExecutionsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTaskExecutionsResponse.SerializeToString,
            ),
            'ListTransformationFunctions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTransformationFunctions,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTransformationFunctionsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTransformationFunctionsResponse.SerializeToString,
            ),
            'GetTransformationFunction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransformationFunction,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetTransformationFunctionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetTransformationFunctionResponse.SerializeToString,
            ),
            'GetBackfillJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBackfillJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.BackfillResponse.SerializeToString,
            ),
            'CreateDraftFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDraftFeatureSet,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateFeatureSetFromDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeatureSetFromDraft,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DraftToFeatureSetRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DraftToFeatureSetResponse.SerializeToString,
            ),
            'DeleteFeatureSetDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureSetDraft,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftId.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListFeatureSetDrafts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSetDrafts,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetDraftsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetDraftsResponse.SerializeToString,
            ),
            'GetFeatureSetDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetDraft,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftResponse.SerializeToString,
            ),
            'StoreFileArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.StoreFileArtifact,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StoreFileArtifactRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StoreFileArtifactResponse.SerializeToString,
            ),
            'RetrieveArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveArtifact,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveArtifactRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveArtifactResponse.SerializeToString,
            ),
            'UpdateUploadStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUploadStatus,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateUploadStatusRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteArtifact,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteArtifactRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListArtifacts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListArtifacts,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListArtifactsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListArtifactsResponse.SerializeToString,
            ),
            'StoreLink': grpc.unary_unary_rpc_method_handler(
                    servicer.StoreLink,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StoreLinkRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListFeatureSetsToReview': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSetsToReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsToReviewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsToReviewResponse.SerializeToString,
            ),
            'ApproveReview': grpc.unary_unary_rpc_method_handler(
                    servicer.ApproveReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ApproveReviewRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RejectReview': grpc.unary_unary_rpc_method_handler(
                    servicer.RejectReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RejectReviewRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListFeatureSetsReviewsPage': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSetsReviewsPage,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetReviewsPageRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetReviewsPageResponse.SerializeToString,
            ),
            'GetListableFeatureSetToReview': grpc.unary_unary_rpc_method_handler(
                    servicer.GetListableFeatureSetToReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetToReviewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetToReviewResponse.SerializeToString,
            ),
            'GetListableFeatureSetInReview': grpc.unary_unary_rpc_method_handler(
                    servicer.GetListableFeatureSetInReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetInReviewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetInReviewResponse.SerializeToString,
            ),
            'DeleteFeatureSetVersionInReview': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureSetVersionInReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteRejectedFeatureSetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListFeaturesToReview': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeaturesToReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesToReviewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesToReviewResponse.SerializeToString,
            ),
            'ListFeaturesInReview': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeaturesInReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesInReviewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesInReviewResponse.SerializeToString,
            ),
            'GetFeatureSetPreviewToReview': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetPreviewToReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewToReviewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewToReviewResponse.SerializeToString,
            ),
            'GetFeatureSetPreviewInReview': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetPreviewInReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewInReviewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewInReviewResponse.SerializeToString,
            ),
            'GetFeatureSetToReview': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetToReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetToReviewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetToReviewResponse.SerializeToString,
            ),
            'GetFeatureSetInReview': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetInReview,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetInReviewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetInReviewResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.h2o.featurestore.api.v1.CoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CoreService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListJobs',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.Job.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJobProgress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetJobProgress',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressInput.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressOutput.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CancelJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListJobsPageByFeatureSetName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListJobsPageByFeatureSetName',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageByFeatureSetNameRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListJobsPageByFeatureSetId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListJobsPageByFeatureSetId',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageByFeatureSetIdRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsPageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJobsWithStatusCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetJobsWithStatusCount',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetJobsWithStatusCountRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetJobsWithStatusCountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartExtractSchemaJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartExtractSchemaJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartExtractSchemaJobRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExtractSchemaJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetExtractSchemaJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExtractSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartIngestJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartIngestJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartIngestJobRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIngestJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetIngestJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartRetrieveAsLinksJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartRetrieveAsLinksJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRetrieveAsLinksJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetRetrieveAsLinksJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsLinksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RetrieveAsSpark(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RetrieveAsSpark',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsSparkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIngestWriteCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetIngestWriteCredentials',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartRevertIngestJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartRevertIngestJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartRevertIngestJobRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRevertIngestJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetRevertIngestJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HasPermissionToRetrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/HasPermissionToRetrieve',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RegisterFeatureSet',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RegisterFeatureSetRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNewFeatureSetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CreateNewFeatureSetVersion',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateNewFeatureSetVersionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOnlineRetrieveMeta(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetOnlineRetrieveMeta',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.OnlineRetrieveMeta.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetVersion',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSet',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetById',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetRequestId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetsLastMinorForCurrentMajor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetsLastMinorForCurrentMajor',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetsLastMinorForCurrentMajorRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureSetVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetVersions',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsVersionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureSet',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureSetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureSetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureSetVersion',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureSetVersionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureSetsPage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetsPage',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPageRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FeatureSetExists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/FeatureSetExists',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetExistsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIngestHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetIngestHistory',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsFeatureSetSchemaCompatible(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/IsFeatureSetSchemaCompatible',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FeatureSetSchemaPatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/FeatureSetSchemaPatch',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetPreview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetPreview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSet',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureSetRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeatureView(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CreateFeatureView',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateFeatureViewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureView(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureView',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureViewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureView(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureView',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureViewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FeatureViewExists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/FeatureViewExists',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewExistsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureViews(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureViews',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureViewsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureViewsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeatureViewNewVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CreateFeatureViewNewVersion',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateFeatureViewNewVersionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureViewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartRetrieveFeatureViewAsSparkJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartRetrieveFeatureViewAsSparkJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsSparkRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRetrieveFeatureViewAsSparkJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetRetrieveFeatureViewAsSparkJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsSparkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartRetrieveFeatureViewAsLinksJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartRetrieveFeatureViewAsLinksJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsAsLinksRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRetrieveFeatureViewAsLinksJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetRetrieveFeatureViewAsLinksJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveFeatureViewAsAsLinksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureView(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureView',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureViewRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateMLDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CreateMLDataset',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateMLDatasetRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateMLDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMLDatasetCreationJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetMLDatasetCreationJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDataset.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMLDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateMLDataset',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateMLDatasetRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDataset.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMLDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteMLDataset',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteMLDatasetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMLDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetMLDataset',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetMLDatasetRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDataset.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MLDatasetExists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/MLDatasetExists',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MLDatasetExistsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMLDatasets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListMLDatasets',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListMLDatasetsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListMLDatasetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RetrieveMLDatasetAsSpark(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RetrieveMLDatasetAsSpark',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsSparkRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsSparkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RetrieveMLDatasetAsLinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RetrieveMLDatasetAsLinks',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsAsLinksRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetAsAsLinksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RetrieveMLDatasetOnline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RetrieveMLDatasetOnline',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveMLDatasetOnlineRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProjectsPage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListProjectsPage',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPageRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CreateProject',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetProject',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetProjectRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteProject',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteProjectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjectsDefault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetProjectsDefault',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectsDefaultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProjectExists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ProjectExists',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectExistsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateProject',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateProjectRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProjectHistoryPage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListProjectHistoryPage',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectHistoryPageRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectHistoryPageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccessToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetAccessToken',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RefreshTokenRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.AccessTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserByMail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetUserByMail',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Logout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/Logout',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LogoutRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActiveUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetActiveUser',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActiveUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ai.h2o.featurestore.api.v1.CoreService/Login',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWebConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetWebConfig',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetWebConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddFeatureSetPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/AddFeatureSetPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddProjectPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/AddProjectPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveFeatureSetPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RemoveFeatureSetPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveProjectPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RemoveProjectPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubmitPendingProjectPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/SubmitPendingProjectPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubmitPendingFeatureSetPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/SubmitPendingFeatureSetPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.SubmitPendingPermissionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProjectPermissionsPage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListProjectPermissionsPage',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPermissionsPageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureSetsPermissionsPage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetsPermissionsPage',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPermissionsPageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListManageableProjectPermissionsPage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListManageableProjectPermissionsPage',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsPermissionsPageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListManageableFeatureSetsPermissionsPage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListManageableFeatureSetsPermissionsPage',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPermissionsPageRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsPermissionsPageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApprovePendingPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ApprovePendingPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ApprovePendingPermissionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RejectPendingPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RejectPendingPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RejectPendingPermissionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokePermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RevokePermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RevokePermissionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActiveProjectPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetActiveProjectPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActiveFeatureSetPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetActiveFeatureSetPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActivePermissionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjectOwners(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetProjectOwners',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetOwners(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetOwners',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetOwnersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserProjectPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetUserProjectPermissions',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserFeatureSetPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetUserFeatureSetPermissions',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserPermissionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RevokeToken',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GenerateToken',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTokenRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RawTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListTokens',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPersonalAccessTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListPersonalAccessTokens',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPersonalAccessTokensRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListPersonalAccessTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetToken',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnlineRetrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/OnlineRetrieve',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnlineIngest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/OnlineIngest',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineIngestRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartMaterializationOnlineJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartMaterializationOnlineJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartMaterializationOnlineRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMaterializationOnlineJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetMaterializationOnlineJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MaterializationOnlineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetComputeStatisticsJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetComputeStatisticsJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetComputeRecommendationClassifiersJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetComputeRecommendationClassifiersJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateTransformationUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GenerateTransformationUpload',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRecommendationClassifiers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListRecommendationClassifiers',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.ListRecommendationClassifierResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRecommendationClassifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CreateRecommendationClassifier',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.CreateRecommendationClassifierRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRecommendationClassifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateRecommendationClassifier',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.UpdateRecommendationClassifierRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRecommendationClassifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteRecommendationClassifier',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.DeleteRecommendationClassifierRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecommendations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetRecommendations',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDashboard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetDashboard',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_DashboardApi__pb2.DashboardResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetsPopularity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetsPopularity',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetsPopularityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecentlyUsedProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetRecentlyUsedProjects',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RecentlyUsedProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecentlyUsedFeatureSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetRecentlyUsedFeatureSets',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RecentlyUsedFeatureSetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PinFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/PinFeatureSet',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PinFeatureSetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnpinFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UnpinFeatureSet',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UnpinFeatureSetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsFeatureSetPinned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/IsFeatureSetPinned',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IsFeatureSetPinnedRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IsFeatureSetPinnedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPinnedFeatureSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListPinnedFeatureSets',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PinnedFeatureSetsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PinnedFeatureSetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/SearchProjects',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectSearchRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectSearchResults.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchFeatureSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/SearchFeatureSets',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSearchRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSearchResults.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchFeatures(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/SearchFeatures',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSearchRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSearchResults.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeature',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatures(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeatures',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeature',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateFeatureResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarkFeatureAsTarget(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/MarkFeatureAsTarget',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TargetFeatureRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DiscardFeatureAsTarget(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DiscardFeatureAsTarget',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TargetFeatureRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTargetFeatures(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListTargetFeatures',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTargetFeaturesRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTargetFeaturesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetListableFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetListableFeatureSet',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListableFeatureSetRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListableFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ScheduleIngestJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ScheduleIngestJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduleTaskRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListScheduledTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListScheduledTasks',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTasksRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTasksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetScheduledTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetScheduledTask',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteScheduledTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteScheduledTask',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskId.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateScheduledTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateScheduledTask',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseScheduledTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/PauseScheduledTask',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PauseScheduledTaskRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeScheduledTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ResumeScheduledTask',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ResumeScheduledTaskRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ScheduleLazyIngestTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ScheduleLazyIngestTask',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduleTaskRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartLazyIngestTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartLazyIngestTask',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LazyIngestRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LazyIngestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLazyIngestTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetLazyIngestTask',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetLazyIngestTaskRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ScheduledTaskResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListScheduledTaskExecutionHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListScheduledTaskExecutionHistory',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTaskExecutionsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListScheduledTaskExecutionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTransformationFunctions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListTransformationFunctions',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTransformationFunctionsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTransformationFunctionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransformationFunction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetTransformationFunction',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetTransformationFunctionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetTransformationFunctionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBackfillJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetBackfillJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.BackfillResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDraftFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CreateDraftFeatureSet',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeatureSetFromDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CreateFeatureSetFromDraft',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DraftToFeatureSetRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DraftToFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureSetDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureSetDraft',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftId.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureSetDrafts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetDrafts',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetDraftsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetDraftsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetDraft',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetDraftResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StoreFileArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StoreFileArtifact',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StoreFileArtifactRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StoreFileArtifactResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RetrieveArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RetrieveArtifact',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveArtifactRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveArtifactResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUploadStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateUploadStatus',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.UpdateUploadStatusRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteArtifact',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteArtifactRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListArtifacts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListArtifacts',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListArtifactsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListArtifactsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StoreLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StoreLink',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StoreLinkRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureSetsToReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetsToReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsToReviewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsToReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApproveReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ApproveReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ApproveReviewRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RejectReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RejectReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RejectReviewRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureSetsReviewsPage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetsReviewsPage',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetReviewsPageRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetReviewsPageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetListableFeatureSetToReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetListableFeatureSetToReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetToReviewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetToReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetListableFeatureSetInReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetListableFeatureSetInReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetInReviewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetListableFeatureSetInReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureSetVersionInReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureSetVersionInReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteRejectedFeatureSetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeaturesToReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeaturesToReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesToReviewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesToReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeaturesInReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeaturesInReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesInReviewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeaturesInReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetPreviewToReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetPreviewToReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewToReviewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewToReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetPreviewInReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetPreviewInReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewInReviewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetPreviewInReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetToReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetToReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetToReviewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetToReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetInReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetInReview',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetInReviewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetInReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
